check_filter_seq: Filter invalid bases in nucleotide sequences

View source: R/utils.R

check_filter_seqR Documentation

Filter invalid bases in nucleotide sequences

Description

This function processes nucleotide sequences by converting characters to uppercase and replacing invalid bases with "". based on the specified method. The function preserves the sequence length and attributes (name and Tm) of each sequence.

Usage

check_filter_seq(seq_list, method)

Arguments

seq_list

Input sequence in 5' to 3' direction. Must be provided as: - A list of sequences with attributes (name and Tm)

method

Method to determine valid bases:

TM_Wallace: Valid bases are "A","B","C","D","G","H","I","K","M","N","R","S","T","V","W" and "Y"

TM_GC: Valid bases are "A","B","C","D","G","H","I","K","M","N","R","S","T","V","W", "X" and "Y"

TM_NN: Valid bases are "A","C","G","I" and "T"

Value

Returns a list of sequences with the same structure as input, where invalid bases are replaced with ""

Author(s)

Junhui Li

References

citation("TmCalculator")


TmCalculator documentation built on Aug. 28, 2026, 5:09 p.m.