| chem_correct | R Documentation |
Apply corrections to melting temperature calculations based on the presence of DMSO and formamide. These corrections are rough approximations and should be used with caution.
chem_correct(
DMSO = 0,
formamide_unit = list(value = 0, unit = "percent"),
dmso_factor = 0.75,
formamide_factor = 0.65,
pt_gc = NULL
)
DMSO |
Percent DMSO concentration in the reaction mixture. Default: 0 DMSO can lower the melting temperature of nucleic acid duplexes. |
formamide_unit |
A list containing formamide concentration information: - value: numeric value of formamide concentration - unit: character string specifying the unit ("percent" or "molar") Default: list(value=0, unit="percent") |
dmso_factor |
Coefficient of melting temperature (Tm) decrease per percent DMSO. Default: 0.75 (von Ahsen N, 2001, PMID:11673362) Other accepted empirical coefficients: 0.5, 0.6, 0.65, 0.675 |
formamide_factor |
Coefficient of melting temperature (Tm) decrease per percent formamide. Default: 0.65 (empirical convention); accepted alternatives: 0.6, 0.72. Hutton (1977) reports 0.60, not the default 0.65. |
pt_gc |
Percentage of GC content in the sequence (0-100 This is used in molar formamide corrections. |
When formamide_unit$unit = "percent": Correction = - factor * percentage_of_formamide
When formamide_unit$unit = "molar": Correction = (0.453 * GC/100 - 2.88) * formamide, from Blake & Delcourt (1996).
Junhui Li
von Ahsen N, Wittwer CT, Schutz E. Oligonucleotide melting temperatures under PCR conditions: nearest-neighbor corrections for Mg2+, deoxynucleotide triphosphate, and dimethyl sulfoxide concentrations with comparison to alternative empirical formulas. Clin Chem 2001, 47:1956-1961.
Blake RD, Delcourt SG (1996). Thermodynamic effects of formamide on DNA stability. NAR 24:2095-2103. <doi:10.1093/nar/24.11.2095>
Hutton JR (1977). Renaturation kinetics and thermal stability of DNA in aqueous solutions of formamide and urea. <doi:10.1093/nar/4.10.3537>
# DMSO correction
chem_correct(DMSO = 3)
# Formamide correction (percent)
chem_correct(formamide_unit = list(value = 1.25, unit = "percent"), pt_gc = 50)
# Formamide correction (molar)
chem_correct(formamide_unit = list(value = 1.25, unit = "molar"), pt_gc = 50)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.