View source: R/generate_complement.R
| generate_complement | R Documentation |
Generate the complementary sequence of a nucleic acid sequence, with an option to reverse it.
generate_complement(input_seq, reverse = FALSE)
input_seq |
Input sequence(s) in 5' to 3' direction. Must be provided as either: - A character string (e.g., c("ATGCG", "GCTAG")) |
reverse |
Logical. If TRUE, the complementary sequence is reversed (3' to 5'). If FALSE (default), the complementary sequence is in the same direction (5' to 3'). |
Returns the complementary sequence(s) in the specified direction.
Junhui Li
citation("TmCalculator")
# Generate complementary sequence in same direction (5' to 3')
generate_complement("ATGCG", reverse = FALSE)
# Generate complementary sequence in reverse direction (3' to 5')
generate_complement("ATGCG", reverse = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.