powered by
The Wallace rule is often used as rule of thumb for approximate melting temperature calculations for primers with 14 to 20 nt length.
tm_wallace(gr_seq, ambiguous = FALSE)
Returns a list of sequences with updated Tm attributes
Pre-processed sequence(s) in 5' to 3' direction. This should be the output from to_genomic_ranges() function.
Ambiguous bases are taken into account to compute the G and C content when ambiguous is TRUE.
Junhui Li
Thein S L , Lynch J R , Weatherall D J , et al. DIRECT DETECTION OF HAEMOGLOBIN E WITH SYNTHETIC OLIGONUCLEOTIDES[J]. The Lancet, 1986, 327(8472):93.
input_seq = c('acgtTGCAATGCCGTAWSDBSY','acgtTGCCCCGGCCGCGCCGTAWSDBSY') #for wallace rule gr_seq <- to_genomic_ranges(input_seq) out <- tm_wallace(gr_seq, ambiguous = TRUE) out out$Options
Run the code above in your browser using DataLab